==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/Diki/DiaryArticle.pm <==
#
# WiKicker
#
#  DiaryArticle.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DiaryArticle.pm,v 1.1 2004/05/30 04:18:30 naney Exp $
#
#

package WiKicker::Diki::DiaryArticle;

use 5.005;
use strict;
use Carp;
use WiKicker::Diki::Article;
use WiKicker::Time;

use vars qw(@ISA);
BEGIN {
  @ISA = qw(WiKicker::Diki::Article);
}

sub _make_html {
  my ($self, $text, $term_list, $environment) = @_;

  my $document_node = $self->_make_document_node($text, $environment);
  return $self->_make_html_fragment($document_node, $environment, $term_list);
}

sub _make_html_fragment {
  my ($self, $document_node, $environment, $term_list) = @_;

  my $last_modified = WiKicker::Time::japanese_date_html_str($self->last_modified,
                                                             'JST');
  my $visitor =
    $self->_create_html_fragment_visitor($environment, $term_list);
  $visitor->visit($document_node);
  $self->{title} = $visitor->title;
  $self->set_explicit_term_list($visitor->env->explicit_term_list);
  $self->set_implicit_term_list($visitor->env->implicit_term_list);
  return $visitor->content;
}

sub _create_html_fragment_visitor {
  my ($self, $environment, $term_list) = @_;

  eval "use WiKicker::Diki::DiaryArticleHtmlFragmentVisitor";
  croak $@ if $@;
  my $visitor = WiKicker::Diki::DiaryArticleHtmlFragmentVisitor->new;
  $visitor->env($self->_create_html_env($environment, $term_list));
  return $visitor;
}


sub title {
  my $self = shift;

  return $self->{title};
}

sub date {
  my $self = shift;

  $self->id =~ /^(\d\d\d\d-\d\d-\d\d)/;
  return $1;
}

sub short_id {

  my $self = shift;

  $self->id =~ /^\d\d\d\d-\d\d-\d\d-(.*)$/;
  return $1;
}

sub _make_document_node {
  my ($self, $text, $environment) = @_;

  return $environment->create_document_parser->parse($text);
}

sub _check_serialize_field {
  my $self = shift;

  $self->_id_format_check;
}

sub _id_format_check {
  my $self = shift;

  croak "no id" unless $self->{id};
  croak "invlaid id" unless $self->{id} =~ /^\d\d\d\d-\d\d-\d\d/;
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/Diki/DiaryArticle.pm <==
#
# WiKicker
#
#  DiaryArticle.pm
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: DiaryArticle.pm,v 1.3 2005/02/27 10:55:35 naney Exp $
#
#

package WiKicker::Diki::DiaryArticle;

use 5.005;
use strict;
use Carp;
use WiKicker::Diki::Article;
use WiKicker::Time;
use WiKicker::HTML;

use vars qw(@ISA);
BEGIN {
  @ISA = qw(WiKicker::Diki::Article);
}

sub _make_html {
  my ($self, $text, $term_list, $environment) = @_;

  my $document_node = $self->_make_document_node($text, $environment);
  return $self->_make_html_fragment($document_node, $environment, $term_list);
}

sub _make_html_fragment {
  my ($self, $document_node, $environment, $term_list) = @_;

  my $last_modified = WiKicker::Time::japanese_date_html_str($self->last_modified,
                                                             'JST');
  my $visitor =
    $self->_create_html_fragment_visitor($environment, $term_list);
  $visitor->visit($document_node);
  $self->{title} = $visitor->title;
  $self->set_explicit_term_list($visitor->env->explicit_term_list);
  $self->set_implicit_term_list($visitor->env->implicit_term_list);
  return $visitor->content;
}

sub _create_html_fragment_visitor {
  my ($self, $environment, $term_list) = @_;

  eval "use WiKicker::Diki::DiaryArticleHtmlFragmentVisitor";
  croak $@ if $@;
  my $visitor = WiKicker::Diki::DiaryArticleHtmlFragmentVisitor->new;
  $visitor->env($self->_create_html_env($environment, $term_list));
  return $visitor;
}


sub title {
  my $self = shift;

  return $self->{title};
}

sub date {
  my $self = shift;

  $self->id =~ /^(\d\d\d\d-\d\d-\d\d)/;
  return $1;
}

sub short_id {

  my $self = shift;

  $self->id =~ /^\d\d\d\d-\d\d-\d\d-(.*)$/;
  return $1;
}

sub set_similar_article_info {
  my ($self, $info) = @_;

  $self->{similar} = $info;
}

sub get_similar_article_info {
  my $self = shift;

  return $self->{similar};
}

# override
sub to_html {
  my ($self, $url) = @_;

  my $last_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->last_modified);
  my $term_list_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->term_list_modified);
  my $result = '<!-- article id: ' . $self->id . " -->\n"
    . '<!-- last modified: ' . $last_modified . " -->\n"
    . '<!-- keyword list last modified: ' . $term_list_modified . " -->\n"
    . $self->html;

  my $similar = $self->get_similar_article_info;
  if (defined $similar && @$similar > 0) {
    my $similar_html = '<hr><ul>';
    for my $s (@$similar) {
      my ($id, $title) = @$s;
      $id =~ /^(\d\d\d\d-\d\d-\d\d)/;
      my $date = $1;
      $similar_html .= qq(<li><a href="$url/d/$id.html">) . WiKicker::HTML::escape($title) . "</a> ($date)</li>";
    }
    $similar_html .= '</ul>';
    warn $similar_html;
    $result =~ s/<div class="comment">/$similar_html<div class="comment">/;
  }
  return $result;
}

sub _make_document_node {
  my ($self, $text, $environment) = @_;

  return $environment->create_document_parser->parse($text);
}

sub _check_serialize_field {
  my $self = shift;

  $self->_id_format_check;
}

sub _id_format_check {
  my $self = shift;

  croak 'no id' unless $self->{id};
  croak 'invlaid id' unless $self->{id} =~ /^\d\d\d\d-\d\d-\d\d/;
}


1;
